@@ -1,4 +1,3 @@
-
 from django.test import SimpleTestCase
 from django.core import mail
 from .testcase import setup_settings
@@ -12,11 +11,11 @@ class TestSendMail(SimpleTestCase):
         """Tests that the function is able to send an email without a
         template."""
         emailer.send_mail(
-            subject='Test Subject',
-            plain_message='Test Message',
-            html_message='<p>Test Message</p>',
-            recipient_list=['test@test.com'],
-            from_email='test@test.com'
+            subject="Test Subject",
+            plain_message="Test Message",
+            html_message="<p>Test Message</p>",
+            recipient_list=["test@test.com"],
+            from_email="test@test.com",
         )
         self.assertEqual(len(mail.outbox), 1)
 
@@ -26,11 +25,11 @@ class TestSendMail(SimpleTestCase):
         setup_settings()
 
         emailer.send_mail(
-            subject='Test Subject',
-            plain_message='Test Message',
-            html_message='<p>Test Message</p>',
-            recipient_list=['test@test.com'],
-            from_email='test@test.com',
-            template='email_signals/tests/test_emailer.html',
+            subject="Test Subject",
+            plain_message="Test Message",
+            html_message="<p>Test Message</p>",
+            recipient_list=["test@test.com"],
+            from_email="test@test.com",
+            template="email_signals/tests/test_emailer.html",
         )
         self.assertEqual(len(mail.outbox), 1)
