@@ -1,6 +1,7 @@
 """Contains utility functions for the email_signals package."""
 
 import typing as _t
+from django.template import loader
 from django.db.models.base import ModelBase
 from django.db.models.fields.related_descriptors import ManyToManyDescriptor
 
@@ -52,10 +53,9 @@ def get_param_from_obj(
     """
     param_parts = param.split(seperator)
     current_object = searchable
-
     while param_parts:
-        param_part = param_parts.pop(0)
 
+        param_part = param_parts.pop(0)
         # Need to search in a dictionary separately as `hasattr` is not
         # supported for dictionaries in python 3.8 and below.
         if isinstance(current_object, dict):
@@ -68,6 +68,16 @@ def get_param_from_obj(
         try:
             if hasattr(current_object, param_part):
                 current_object = getattr(current_object, param_part)
+
+                # If the current object is a field, then at this point, the
+                # current object may be a relation descriptor. If this is the
+                # case, we need to We point the current object to the related
+                # model.
+                if (
+                    hasattr(current_object, "field")
+                    and current_object.field.is_relation
+                ):
+                    current_object = current_object.field.related_model
                 continue
         except Exception:
             return False, None
@@ -141,3 +151,26 @@ def get_model_attr_names(model_class: ModelBase, seen_attrs=None) -> dict:
                 )
 
     return attr_names
+
+
+def add_context_to_string(template_str: str, context: dict) -> str:
+    """Add the context to the template string.
+
+    Args:
+        template_str: The template string to add the context to.
+        context: The context to add to the template string.
+
+    Returns:
+        str: The template string with the context added.
+    """
+    engines = loader._engine_list()
+    for engine in engines:
+        try:
+            template = engine.from_string(template_str)
+            return template.render(context)
+        except AttributeError:
+            continue
+    else:
+        raise ValueError(
+            "Could not find a template engine that can render the string."
+        )
